package com.zd.laboratory.service.impl;

import java.util.List;

import com.zd.common.core.utils.DateUtils;
import com.zd.common.core.utils.SecurityUtils;
import com.zd.common.security.utils.SaveUtil;

import com.zd.common.core.utils.Pinyin4jUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zd.laboratory.mapper.LabHazardBookMapper;
import com.zd.laboratory.domain.LabHazardBook;
import com.zd.laboratory.service.ILabHazardBookService;

/**
 * 危化品安全技术说明书Service业务层处理
 *
 * @author liubo
 * @date 2021-11-19
 */
@Service
public class LabHazardBookServiceImpl implements ILabHazardBookService {
    @Autowired
    private LabHazardBookMapper labHazardBookMapper;

    /**
     * 查询危化品安全技术说明书
     *
     * @param id 危化品安全技术说明书主键
     * @return 危化品安全技术说明书
     */
    @Override
    public LabHazardBook selectLabHazardBookById(Long id) {
        LabHazardBook hazardBook = labHazardBookMapper.selectLabHazardBookById(id);
        return hazardBook;
    }

    /**
     * 查询危化品安全技术说明书列表
     *
     * @param labHazardBook 危化品安全技术说明书
     * @return 危化品安全技术说明书
     */
    @Override
    public List<LabHazardBook> selectLabHazardBookList(LabHazardBook labHazardBook) {
        List<LabHazardBook> list = labHazardBookMapper.selectLabHazardBookList(labHazardBook);
        return list;
    }

    /**
     * 新增危化品安全技术说明书
     *
     * @param labHazardBook 危化品安全技术说明书
     * @return 结果
     */
    @Override
    public LabHazardBook insertLabHazardBook(LabHazardBook labHazardBook) {
        //设置其他公共字段
        SaveUtil.setCommonAttr(labHazardBook);
        labHazardBook.setPinYin(Pinyin4jUtil.getPingYin(labHazardBook.getName()));
        labHazardBook.setPinYinChar(Pinyin4jUtil.getPinYinHeadChar(labHazardBook.getName()));
        labHazardBookMapper.insertLabHazardBook(labHazardBook);
        return labHazardBook;
    }

    /**
     * 修改危化品安全技术说明书
     *
     * @param labHazardBook 危化品安全技术说明书
     * @return 结果
     */
    @Override
    public LabHazardBook updateLabHazardBook(LabHazardBook labHazardBook) {
        labHazardBook.setUpdateTime(DateUtils.getNowDate());
        labHazardBook.setUpdateBy(SecurityUtils.getUsername());
        labHazardBook.setPinYin(Pinyin4jUtil.getPingYin(labHazardBook.getName()));
        labHazardBook.setPinYinChar(Pinyin4jUtil.getPinYinHeadChar(labHazardBook.getName()));
        labHazardBookMapper.updateLabHazardBook(labHazardBook);
        return labHazardBook;
    }

    /**
     * 批量删除危化品安全技术说明书
     *
     * @param ids 需要删除的危化品安全技术说明书主键
     * @return 结果
     */
    @Override
    public int deleteLabHazardBookByIds(Long[] ids) {
        return labHazardBookMapper.deleteLabHazardBookByIds(ids);
    }

    /**
     * 删除危化品安全技术说明书信息
     *
     * @param id 危化品安全技术说明书主键
     * @return 结果
     */
    @Override
    public int deleteLabHazardBookById(Long id) {
        return labHazardBookMapper.deleteLabHazardBookById(id);
    }


    /**
     * 查询危化品安全技术说明书关联的化学品列表
     *
     * @param labHazardBook 危化品安全技术说明书
     * @return 危化品安全技术说明书
     */
    @Override
    public List<LabHazardBook> hazardBookJoinChemical(LabHazardBook labHazardBook) {
        List<LabHazardBook> list = labHazardBookMapper.hazardBookJoinChemical(labHazardBook);
        return list;
    }
}
